#include <gtkmm.h>
#include <libglademm.h>
#include <sigc++/sigc++.h>

class ExampleWindow : public SigC::Object {
  Glib::RefPtr<Gnome::Glade::Xml> ui_;
  Gtk::Window* window_;
public:
  ExampleWindow(Gtk::Window&);

  Gtk::Window& get_window() { return *window_; }

  void on_show() { window_->show(); }
  void raise() { window_->deiconify(); window_->raise(); }
  bool on_delete_event(GdkEventAny*) { window_->hide(); return true; }
};

ExampleWindow::ExampleWindow(Gtk::Window& parent)
{
  ui_ = Gnome::Glade::Xml::create("does_not_work.glade");
  ui_->get_widget("window1", window_);

  window_->set_transient_for(parent);
  window_->set_type_hint(Gdk::WINDOW_TYPE_HINT_UTILITY); // does not work, looks like an ordinary window

  window_->signal_delete_event().connect(SigC::slot(*this, &ExampleWindow::on_delete_event));
  window_->signal_show().connect(SigC::slot(*this, &ExampleWindow::on_show));
}

class MainWindow : public Gtk::Window {
  Gtk::VBox vbox_;
  Gtk::Button button_;
  std::auto_ptr<ExampleWindow> example_window_;
public:
  MainWindow();

  void show_example_window()
  {
    if(example_window_.get() == 0) {
      example_window_.reset(new ExampleWindow(*this));
      example_window_->get_window().show();
    }
    else {
      example_window_->get_window().show();
      example_window_->get_window().raise();
    }
  }
};

MainWindow::MainWindow()
  : button_("Show example window")
{
  add(vbox_);
  vbox_.pack_start(button_);

  button_.signal_clicked().connect(SigC::slot(*this, &MainWindow::show_example_window));

  show_all_children();
}

int main(int argc, char *argv[])
{
  Gtk::Main kit(argc, argv);

  MainWindow mw;
  Gtk::Main::run(mw);

  return 0;
}
